@@ -10,14 +10,13 @@ import importlib
 import yaml
 import logging
 from .globals import ctx
-from .ext import __autoload__
 from .interface import InterfaceFactory
-from .helpers import *
+from .utils import *
 from .reporter import Reporter
 from .logger import StdoutToFileLogger
 
 
-class Application(object):
+class Application:
     """the Application object implements the basic entry of
     minimo framework.
     """
@@ -25,27 +24,24 @@ class Application(object):
     # project name, set in project instance
     name = "minimo"
 
-    # project type, default is "minimo"
-    project_type = "minimo"
-
     # report format type, supported "text", "html" and "xml",
     # default is "html"
     #   text: plain text
     #   html: html web page
     #   xml: xml file, can be recognized by most CI system
-    output = "text"
+    # output = "text"
 
     # case running type, should be "serial" or "concorrence",
     # default is "serial"
     #   serial: run cases one by one
     #   concorrence: run cases concorrently by threads.
-    running_type = "serial"
+    # running_type = "serial"
 
     # redirect stdout message to log file or not.
     # if running in background, there maybe raises exception due to no stdout
     # handler, so set this flag to True, print stdout message to log file.
     # it is forced to redirection under api mode.
-    redirect_stdout_to_file = False
+    # redirect_stdout_to_file = False
 
     # project modules path, which will be inserted into sys.path at application
     # started. by default, "lib", "ext", "cases", "vendor" will be added
@@ -59,26 +55,24 @@ class Application(object):
         # root path of project instance
         self.inst_path = attrs.pop("root_path", None)
 
+        # flags intializing
+        self._loaded_modules_path = False
+
         # project interface, supported "cli", "api", default is "cli"
         #   cli: call commands/functions as command line interface
         #   api: call commands/functions as api
         self.interface = attrs.pop("interface", "cli")
+        self._interf = InterfaceFactory.get(
+            self.interface, **attrs)
 
-        # flags intializing
-        self._loaded_plugins = \
-            self._loaded_extensions = \
-            self._loaded_modules_path = False
+        # load plugins and extensions
+        self._load_plugins()
+        self._load_extensions()
 
         # load config from yaml under project instance's root_path
         self._load_config()
 
-        self.__interface = InterfaceFactory.get(self.interface, **attrs)
-
-        # add default cli
-        for cli in __autoload__:
-            self.__interface.add_command(cli)
-
-        ctx.app = self
+        # ctx.app = self
 
     def run(self, *args, **kwargs):
         """alias for :meth:`main`."""
@@ -91,38 +85,27 @@ class Application(object):
         self.main(*args, **kwargs)
 
     def main(self, *args, **kwargs):
-        """main function entry, we just load modules path to sys.path before
-        app running up.
-        """
+        """main function entry"""
 
         self._setup()
 
-        result = self.__interface.main(*args, **kwargs)
+        result = self._interf.main(*args, **kwargs)
 
         self._teardown()
 
         return result
 
     def get_command(self, context, name):
-        """ We load plugins and extension with built-in commands as these
-        should always be the same no matter what the app does.
-        """
+        """wrapper for get_command"""
 
-        self._load_plugins()
-        self._load_extensions()
-
-        return self.__interface.get_command(self, context, name)
+        return self._interf.get_command(self, context, name)
 
     def list_commands(self, context):
-        """we always load plugins and extensions with minimo
-        builtin commands.
-        """
+        """wrapper for list_command"""
 
-        self._load_plugins()
-        self._load_extensions()
-
-        rv = set(self.__interface.list_commands(self, context))
-        return sorted(rv)
+        return sorted(
+            set(self._interf.list_commands(self, context))
+        )
 
     def is_cli_mode(self):
         return "cli" == self.interface
@@ -133,7 +116,7 @@ class Application(object):
     def echo_to_file(self):
         """check out if print console message to file"""
 
-        return self.redirect_stdout_to_file or self.is_api_mode()
+        return ctx.config.redirect_stdout_to_file or self.is_api_mode()
 
     def echo_to_stdout(self):
         """check out if print console message to stdout"""
@@ -165,12 +148,20 @@ class Application(object):
         if self.inst_path is not None:
             config_path = os.path.join(self.inst_path, "config.yml")
             if self.inst_path is not None and os.path.exists(config_path):
-                with open(config_path, "r") as f:
+                with open(config_path, mode="r", encoding="utf-8") as f:
                     # load yml to config and app attributes
                     cfg = yaml.full_load(f.read())
                     if isinstance(cfg, dict):
                         ctx.config.update(cfg)
-                        self.__dict__.update(ctx.config)
+                        ctx.app.update({
+                            "name": self.name,
+                            "inst_path": self.inst_path,
+                            "interface": self.interface,
+                            "is_cli_mode": self.is_cli_mode(),
+                            "is_api_mode": self.is_api_mode(),
+                            "echo_to_file": self.echo_to_file(),
+                            "echo_to_stdout": self.echo_to_stdout(),
+                        })
 
     def _init_context(self):
         """initialize runtime context"""
@@ -213,18 +204,13 @@ class Application(object):
     def _load_plugins(self):
         """load plugins which were registered as 'minimo.commands'."""
 
-        if self._loaded_plugins:
-            return
-
         try:
             import pkg_resources
         except ImportError:
-            self._loaded_plugins = True
             return
 
         for ep in pkg_resources.iter_entry_points('minimo.commands'):
-            self.__interface.add_command(ep.load(), ep.name)
-        self._loaded_plugins = True
+            self._interf.add_command(ep.load(), ep.name)
 
     def _load_extensions(self):
         """load extensions for minimo style project. such extensions will be
@@ -233,18 +219,13 @@ class Application(object):
         automatically.
         """
 
-        if self._loaded_extensions:
-            return
-
         if self.inst_path is not None \
            and os.path.exists(os.path.join(self.inst_path, "ext")):
             try:
-                for cli in importlib.import_module("ext").__autoload__:
-                    self.__interface.add_command(cli)
+                for cmd in importlib.import_module("ext").__autoload__:
+                    self._interf.add_command(cmd)
             except Exception:
                 # do nothing
-                self._loaded_extensions = True
                 return
-        self._loaded_extensions = True
 
 # end
