@@ -9,11 +9,11 @@ import os
 import copy
 import yaml
 from .globals import *
-from .helpers import *
+from .utils import *
 from .logger import Logger
 
 
-class Performer(object):
+class Performer:
     """mini-mo base performer to perform task case.
 
     :attr name: performer name
@@ -61,7 +61,7 @@ class Performer(object):
         if logger is None:
             self.logger = Logger(name=self.name,
                                  output_path=ctx.output_path,
-                                 stdout=ctx.app.echo_to_stdout())
+                                 stdout=ctx.app.echo_to_stdout)
         else:
             self.logger = logger
 
@@ -99,7 +99,7 @@ class Performer(object):
         if self.case_path is not None:
             config_path = os.path.join(self.case_path, "config.yml")
             if os.path.exists(config_path):
-                with open(config_path, "r") as f:
+                with open(config_path, mode="r", encoding="utf-8") as f:
                     # load yml to config
                     cfg = yaml.full_load(f.read())
                     if isinstance(cfg, dict):
