@@ -2,16 +2,11 @@
 import os
 import minimo
 import traceback
-from mako.template import Template
 
 
-TRACE_SPLITTER = "*" * 50
-
-
-mmo = minimo.Application(interface="api")
-
+# mmo = minimo.Application(interface="api")
 # return True or False for `init` result
-result = mmo.call("init", name="helloKitty")
+# result = mmo.call("init", name="helloKitty")
 
 
 # # inst_path = os.path.dirname(__file__)
@@ -26,3 +21,15 @@ result = mmo.call("init", name="helloKitty")
 # # print mmo.call("init", name="hello_kitty")
 # print mmo.call("new", cases=["hello", "shithappens/init", "shithappens/delete"])
 # # end
+
+inst_path = os.path.join(os.path.dirname(__file__), "dejavu")
+mmo = minimo.Application(
+    interface="api",
+    root_path=inst_path
+)
+mmo.call(
+    "run",
+    cases=["bots/hell", "cat/hell"]
+)
+
+# end
